@@ -21,11 +21,11 @@ from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN
      load_life_expectancy, load_electric_devices, load_energy, load_arxiv, load_attrition, \
      load_literature, load_translation, load_heart_failure, load_MNIST, load_darwin, \
      load_bands, load_NASDAQ, load_sentiment, load_BCN_cesta, load_BCN_ruido, load_credit_scoring, \
-          load_king_county_houses
+          load_king_county_houses, load_wages
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
-__version__ = "0.1.10"
+__version__ = "0.1.11"
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -54,5 +54,6 @@ __all__ = ['fetch_apa_data',
            'load_BCN_cesta',
            'load_BCN_ruido',
            'load_credit_scoring',
-           'load_king_county_houses'
+           'load_king_county_houses',
+           'load_wages'
            ]
